@@ -1,6 +1,8 @@
 from logging import getLogger
 from pathlib import Path
 
+from typer import Option
+
 from deckz.cli import app
 from deckz.paths import Paths
 from deckz.uploading import Uploader
@@ -9,7 +11,11 @@ _logger = getLogger(__name__)
 
 
 @app.command()
-def upload(deck_path: Path = Path(".")) -> None:
+def upload(
+    workdir: Path = Option(
+        Path("."), help="Path to move into before running the command"
+    )
+) -> None:
     """Upload pdfs to Google Drive."""
-    paths = Paths.from_defaults(deck_path)
+    paths = Paths.from_defaults(workdir)
     Uploader(paths)
