@@ -1,28 +1,75 @@
 from contextlib import redirect_stdout
 from functools import partial
+from importlib import invalidate_caches, reload
+from importlib.util import module_from_spec, spec_from_file_location
 from itertools import chain
 from logging import getLogger
 from multiprocessing import Pool
 from pathlib import Path
-from shutil import copyfile
+from shutil import copyfile, rmtree
 from tempfile import TemporaryDirectory
+from unittest.mock import patch
 
+import deckz.plot_utils  # noqa: F401
 from deckz.compiling import CompilePaths
 from deckz.compiling import compile as compiling_compile
 from deckz.exceptions import DeckzException
 from deckz.paths import GlobalPaths
+from deckz.plot_utils import _create_tailored_save_function
 from deckz.settings import Settings
 from deckz.utils import copy_file_if_newer
 
 
 class StandalonesBuilder:
+    def __init__(self, settings: Settings, paths: GlobalPaths):
+        self.plt_builder = PltBuilder(settings, paths)
+        self.tikz_builder = TikzBuilder(settings, paths)
+
+    def build(self) -> None:
+        self.plt_builder.build()
+        self.tikz_builder.build()
+
+
+class PltBuilder:
+    def __init__(self, settings: Settings, paths: GlobalPaths):
+        self._settings = settings
+        self._paths = paths
+        self._logger = getLogger(__name__)
+
+    def build(self) -> None:
+        self._clean_plt_dir()
+        to_process = self._paths.shared_plt_dir.rglob("*.py")
+        for python_file in to_process:
+            with patch(
+                "deckz.plot_utils.save",
+                new=_create_tailored_save_function(self._paths, python_file),
+            ):
+                spec = spec_from_file_location("mod", python_file)
+                mod = module_from_spec(spec)
+                try:
+                    reload(mod)
+                except Exception:
+                    spec.loader.exec_module(mod)  # type: ignore
+
+    def _clean_plt_dir(self) -> None:
+        files_to_clean = chain(
+            self._paths.shared_plt_dir.rglob("*.pyc"),
+            self._paths.shared_plt_dir.rglob("*.pyo"),
+        )
+        for f in files_to_clean:
+            f.unlink()
+        for d in self._paths.shared_plt_dir.rglob("__pycache__"):
+            rmtree(d)
+        invalidate_caches()
+
+
+class TikzBuilder:
     def __init__(self, settings: Settings, paths: GlobalPaths):
         self._paths = paths
         self._settings = settings
         self._logger = getLogger(__name__)
 
     def build(self) -> None:
-        self._logger.info("Processing standalones")
         with TemporaryDirectory() as build_dir:
             build_path = Path(build_dir)
             items = [
@@ -37,6 +84,11 @@ class StandalonesBuilder:
                 )
             ]
 
+            if not items:
+                return
+
+            self._logger.info(f"Processing {len(items)} tikz that need recompiling")
+
             for item in items:
                 self._prepare(*item)
 
