@@ -1,7 +1,7 @@
 from pathlib import Path
 from shutil import copyfile
 
-from pygit2 import discover_repository, Repository
+from pygit2 import Repository, discover_repository
 
 from deckz.exceptions import DeckzException
 
